==> dorm-1.0.17.tar.gz: lib/src/domain/meta.dart <==
part of dorm;

//-----------------------------------
// Ref annotation
//-----------------------------------

class Ref {
  
  final String path;
  
  const Ref(this.path);
  
  String toString() => path;
  
}

//-----------------------------------
// Property annotation
//-----------------------------------

class Property {
  
  final Symbol propertySymbol;
  final String property;
  final Type type;
  final String expectedTypeAsString;
  
  const Property(this.propertySymbol, this.property, this.type, this.expectedTypeAsString);
  
  String toString() => 'property $property';
  
}

//-----------------------------------
// NotNullable annotation
//-----------------------------------

class NotNullable {
  
  const NotNullable();
  
  String toString() => 'not nullable';
  
}

//-----------------------------------
// DefaultValue annotation
//-----------------------------------

class DefaultValue {
  
  final dynamic value;
  
  const DefaultValue(this.value);
  
  String toString() => 'default $value';
  
}

//-----------------------------------
// Transient annotation
//-----------------------------------

class Transient {
  
  const Transient();
  
  String toString() => 'transient';
  
}

//-----------------------------------
// Id annotation
//-----------------------------------

class Id {
  
  final dynamic insertValue;
  
  const Id(this.insertValue);
  
  String toString() => 'id $insertValue';
  
}

//-----------------------------------
// Immutable annotation
//-----------------------------------

class Immutable {
  
  const Immutable();
  
  String toString() => 'immutable';
  
}

//-----------------------------------
// Lazy annotation
//-----------------------------------

class Lazy {
  
  const Lazy();
  
  String toString() => 'lazy';
  
}

//-----------------------------------
// LabelField annotation
//-----------------------------------

class LabelField {
  
  const LabelField();
  
  String toString() => 'label field';
}

//-----------------------------------
// Silent annotation
//-----------------------------------

class Silent {
  
  const Silent();
  
  String toString() => 'silent';
}

//-----------------------------------
// Transform annotation
//-----------------------------------

class Transform {
  
  final String from, to;
  
  const Transform(this.from, this.to);
  
  String toString() => 'transform $from to $to';

}

//-----------------------------------
// Generic annotation
//-----------------------------------

class Annotation {
  
  final Map<String, dynamic> params;
  
  const Annotation(this.params);
  
  String toString() => 'generic annotation';
}

==> dorm-1.0.37.tar.gz: lib/src/domain/meta.dart <==
part of dorm;

//-----------------------------------
// Ref annotation
//-----------------------------------

class Ref {
  
  final String path;
  
  const Ref(this.path);

  @override String toString() => path;
  
}

//-----------------------------------
// Property annotation
//-----------------------------------

class Property {
  
  final Symbol propertySymbol;
  final String property;
  final Type type;
  final String expectedTypeAsString;
  
  const Property(this.propertySymbol, this.property, this.type, this.expectedTypeAsString);
  
  @override String toString() => 'property $property';
  
}

//-----------------------------------
// NotNullable annotation
//-----------------------------------

class NotNullable {

  String get ident => 'notNullable';
  
  const NotNullable();

  @override String toString() => 'not nullable';
  
}

//-----------------------------------
// DefaultValue annotation
//-----------------------------------

class DefaultValue {

  String get ident => 'defaultValue';
  
  final dynamic value;
  
  const DefaultValue(this.value);

  @override String toString() => 'default $value';
  
}

//-----------------------------------
// Transient annotation
//-----------------------------------

class Transient {

  String get ident => 'transient';
  
  const Transient();

  @override String toString() => 'transient';
  
}

//-----------------------------------
// Id annotation
//-----------------------------------

class Id {

  String get ident => 'id';
  
  final dynamic insertValue;
  
  const Id(this.insertValue);

  @override String toString() => 'id $insertValue';
  
}

//-----------------------------------
// Immutable annotation
//-----------------------------------

class Immutable {

  String get ident => 'immutable';
  
  const Immutable();

  @override String toString() => 'immutable';
  
}

//-----------------------------------
// LabelField annotation
//-----------------------------------

class LabelField {

  String get ident => 'labelField';
  
  const LabelField();

  @override String toString() => 'label field';
}

//-----------------------------------
// Silent annotation
//-----------------------------------

class Silent {

  String get ident => 'silent';
  
  const Silent();

  @override String toString() => 'silent';
}

//-----------------------------------
// Transform annotation
//-----------------------------------

class Transform {

  String get ident => 'transform';
  
  final String from, to;
  
  const Transform(this.from, this.to);

  @override String toString() => 'transform $from to $to';

}

//-----------------------------------
// Generic annotation
//-----------------------------------

class Annotation {

  String get ident => 'generic';
  
  final Map<String, dynamic> params;
  
  const Annotation(this.params);

  @override String toString() => 'generic annotation';
}
